import styled from 'styled-components'
import { Button, Modal } from 'antd'

export type UserAgreementModalProps = {
  title: string
  show: boolean
  onCancel: VoidFunction
}

export default function UserAgreementModal({ title, show, onCancel }: UserAgreementModalProps) {
  return (
    <Modal
      title={title}
      open={show}
      onCancel={onCancel}
      footer={[
        <Button key='back' onClick={onCancel}>
          关 闭
        </Button>
      ]}>
      <AgreementWrapper className='h-[500px] overflow-y-auto'>
        <p className='title mb-[20px] bold-text text-center'>要易云平台用户协议</p>
        <p className='text-right'>第1.0版</p>
        <p className='underline-bold'>
          《平台用户协议》系由您（或称“用户”）与深圳要易云科技服务有限公司（或称“要易云”）之间就您使用要易云平台的（以下或简称“本平台”）服务而签订。本平台依据《平台用户协议》的规定提供服务，该协议一旦生效对用户及要易云均产生法律效力。您在用户注册时，请认真阅读本协议，审阅并选择同意或不同意本协议。
        </p>
        <p className='underline-bold'>
          在使用本平台服务之前，请您务必审慎阅读、充分理解本协议各项条款，特别是限制或免除责任条款、隐私保护政策、账号规则、法律适用和争议解决条款（包括管辖条款），以及其它以加粗加黑和/或加下划线等显著形式提示您注意的重要条款，请务必重点查阅。
        </p>
        <p className='underline-bold'>
          要易云与您将通过数据电文形式订立本协议，若您不同意本协议，则您有充分且完全的权利立即停止成为本平台用户的注册程序。您通过网络页面点击“同意”的按钮并且该注册和/或实际使用平台服务的行为即视为您已阅读、充分理解并同意接受本协议的全部条款含义及相应的法律后果，不可撤销地同意与要易云以数据电文形式订立本协议并受本协议条款及其后续修订版本的全部约束，本协议在您点击“同意”并实际使用平台服务时成立生效。如果您对本协议有任何的疑问、投诉、意见和建议，欢迎您通过本协议所附联系方式与要易云沟通反馈。
        </p>
        <p className='bold-text'>第1条 基础约定事项</p>
        <p>
          1.1
          协议范围：考虑到互联网服务以及商品频繁迭代更新等行业特点，为了更全面的界定您与本平台之间的权利义务，
          <span className='underline-bold'>
            本协议包括要易云根据法律法规规定制定的其他政策、规则、公告声明等（除非特有所指，以上合称为“本协议”）
          </span>
          ，您应当加以遵守。
        </p>
        <p>
          1.2
          服务范围：要易云可能通过不断丰富的功能界面向您提供本协议项下的平台服务，包括但不限于PC端网站以及其他形式。具体以要易云实时发布的服务功能界面范围为准。
        </p>
        <p>
          1.3 主体地位：请您在接受本协议或者以其他要易云允许的方式实际使用本服务之前，
          <span className='underline-bold'>
            请确保您是适格的合同主体，并在清楚理解本协议内容及其法律后果后自行决定是否同意签署，而且就您所知，您不存在任何可能使得本协议无效或者对本协议项下义务的履行产生重大不利影响之情形。
          </span>
        </p>
        <p className='bold-text'>第2条 用户资格</p>
        <p>2.1 只有符合下列条件的机构才能申请成为本平台用户，可以使用本平台的服务：</p>
        <p>
          2.1.1
          <span className='underline-bold'>非自然人用户：</span>
        </p>
        <p className='underline-bold'>
          （1）根据中国法律、法规、行政规章合法设立并有效存续的机关、企事业单位、社团组织和其他组织；
        </p>
        <p className='underline-bold'>
          （2）未被国家企业信用信息公示系统(www.gsxt.gov.cn)列入严重违法失信企业名录；
        </p>
        <p className='underline-bold'>（3）未被责令停业或处于破产状态的；</p>
        <p className='underline-bold'>（4）财产及其股权未处于重组、接管、查封、扣押或冻结状态；</p>
        <p className='underline-bold'>（5）近三年内不涉及重大诉讼、仲裁，不属于失信被执行人的；</p>
        <p className='underline-bold'>（6）不存在违反法律法规规定的其他情形。</p>
        <p>
          2.2
          <span className='underline-bold'>
            不符合以上条件的法人或其他组织，将不被允许注册及认证成为本平台用户，且不得使用本平台相关服务，本平台一经发现，有权立即终止对该用户的服务，并追究其使用本平台服务的一切法律责任。
          </span>
        </p>
        <p>
          2.3
          <span className='underline-bold'>
            非自然人用户需通过授权自然人为管理员后进行操作及管理。
          </span>
        </p>
        <p>2.4 用户需要提供真实有效的联系电话，并提供真实信息。</p>
        <p>
          2.5
          本平台用户须承诺遵守法律法规、社会主义制度、国家利益、公民合法权益、公共秩序、社会道德风尚和信息真实性。
        </p>
        <p className='bold-text'>第3条 用户账号及资金账户规则</p>
        <p>3.1 用户账号</p>
        <p>
          3.1.1
          您通过平台或上级企业管理员获得要易云配置的用户账号，自首次使用该账号登录并使用平台服务之日起即成为平台用户（以下称“注册”），您在使用本平台服务时可能需要提供一些必要的信息，具体以本网站相关页面提示为准。您须保证所填写及所提供的资料真实、准确、完整，否则可能无法使用本平台服务，或在使用过程中受到限制，甚至影响您正常使用本平台特定功能。
          <span className='underline-bold'>
            对于因您提供的信息不真实、不准确或不完整导致的责任和损失由您自行承担。
          </span>
        </p>
        <p>
          3.1.2
          <span className='underline-bold'>
            您有责任自行负责保管账号的用户名和登录密码等信息，否则因该等事项引发的法律责任由用户自行承担（例如账户被盗用、转让等）。凡使用本平台服务登录账号和登录凭证的行为，本平台服务视为您本人的操作，操作所产生的电子信息记录均为本平台服务用户行为的有效凭据。
          </span>
        </p>
        <p>3.2 账号锁定</p>
        <p>
          3.2.1 用户申请锁定情形
          账号锁定指，在本平台执行某账户进行锁定后，该用户将不能登录该账户、进而不能使用平台项下全部功能。如果您需要锁定您的账号，您可以通过联系平台客服进行申请，经本平台审核同意后方可解除与本平台的协议关系并锁定您账号。当您的账户锁定后，您的个人信息和您在使用要易云服务期间提供或产生的信息我们将按照《要易云隐私政策》第三条第三款约定的存储期限进行保存。
        </p>
        <p>3.5.2 强制锁定情形</p>
        <p className='underline-bold'>
          要易云有权在您的账号符合如下情况时，锁定您的账号并停止服务：
        </p>
        <p className='underline-bold'>（1）连续180日未曾登录、使用本平台服务；</p>
        <p className='underline-bold'>
          （2）在用户违反本协议及相关规则规定时，本平台有权终止向该用户提供服务。但该用户在被本平台终止提供服务后，再一次直接或间接或以他人名义注册为本平台用户的，一经发现，本平台有权再次单方面终止为该用户提供服务；
        </p>
        <p className='underline-bold'>
          （3）本平台发现用户注册资料中主要内容是虚假的，本平台有权随时终止为该用户提供服务；
        </p>
        <p className='underline-bold'>（4）本协议终止或更新时，用户未确认新的协议的；</p>
        <p className='underline-bold'>
          （5）其它本平台认为需终止服务的情况。
          有以上强制锁定情形的，本平台可自行全权决定，在发出通知或不发出通知的情况下，随时停止或终止提供全部或部分服务。服务终止后，本平台没有义务为用户保留原账户中或与之相关的任何信息，或在出现强制锁定情形后转发任何未曾阅读或发送的信息给用户或第三方。
        </p>
        <p>3.5.3 账户锁定资金结算</p>
        <p className='underline-bold'>
          要易云将在您与平台其他用户清理、结算账户资产及纠纷争议后，为您提供账号锁定服务。在锁定账号之后，要易云将停止为您提供任何服务。但因强制锁定的，要易云有权在资金及纠纷处理完毕且锁定该账户，使其无法正常使用任何功能直至相关纠纷处理完毕。
        </p>
        <p>3.5.4 不论用户账户通过何种方式锁定，本平台仍保留下列权利：</p>
        <p>
          本平台有权在法律、法规、行政规章规定的时间内保留该用户的资料，包括但不限于以前的用户资料、操作记录等；保留期限详见《要易云隐私政策》。
        </p>
        <p className='bold-text'>第4条 平台交易规则</p>
        <p>您承诺与本平台其他用户进行交易的过程中，应良好遵守如下基本交易规则：</p>
        <p>4.1 了解服务信息</p>
        <p>
          您在通过本平台交易前，应详细了解并完全接受本平台服务内容及操作规则，方可进行操作或签署协议进行交易。
        </p>
        <p>4.2 数据信息保护</p>
        <p className='underline-bold'>
          关于您在向合作的第三方服务商发起的准入信息申报邀请时所收集到的信息，需用仅用于您对于其准入需求，不可用于外部分享或其他用途。
        </p>
        <p>4.3 其他规则说明</p>
        <p>
          4.3.1
          为交易达成以及用户体验提升等目的，本平台可能会为您提供更为友好完善的交易规则服务，并引入第三方服务。第三方服务主要为您提供企业管理所查询到的数据信息和发票管理对应的发票数据信息。
        </p>
        <p>
          4.3.2
          您同意并知悉，本平台中的具体内容、功能和形式由平台根据实际情况按“现状”实时提供，要易云有权自行确定本平台服务的具体内容、功能和形式，有权自行决定增加、变更、中断和停止本平台具体的内容、功能和形式。具体以本平台实时呈现的服务内容、功能和形式为准。
        </p>
        <p>
          4.3.3
          <span className='underline-bold'>
            由于众所周知的互联网技术因素等客观原因存在，本平台显示的信息可能会有一定的滞后性或差错，对此情形您知悉并理解。如因系统故障或平台重大误解导致显示信息明显不合理的，请勿进行下一步操作，如您明知显示信息明显不合理仍然提交交易文件的，将可能被视为恶意行为，本平台将有权取消本次交易；如果您在不知情的情况下进行了下一步操作，请第一时间联系本平台客服。
          </span>
        </p>
        <p>
          4.3.4
          <span className='underline-bold'>
            您同意在使用本平台服务的过程中遵守诚实信用原则，您不得实施恶意行为扰乱本平台正常秩序。如本平台根据您的登录账号下的操作记录及其他相关信息，发现您有（或可能有）恶意行为的，则本平台有权单方拒绝您的需求，或单方取消您的操作且不予退还保证金（如有），且无须由此向您承担法律责任。
          </span>
        </p>
        <p className='bold-text'>第5条 用户的权利和义务</p>
        <p>
          5.1
          用户有权根据本协议及本平台发布的相关规则，登录并利用本平台查询公开的企业相关信息、发票状态信息、收集合作第三方服务商准入信息等，并有权享受本平台提供的其他有关资讯及信息服务。
        </p>
        <p>
          5.2
          <span className='underline-bold'>
            用户有权对部分自身账号相关信息进行查询、更新。用户有权对自身账号对应的用户信息、操作信息、汇总信息等相关信息进行查询，用户可以按其权限进行操作处理，例如管理员可按权限创建账户、查询第三方企业公开信息、发票状态信息、收集合作第三方服务商准入信息等。
          </span>
        </p>
        <p>
          5.3
          <span className='underline-bold'>
            用户须自行管理自己的用户账号和密码或者验证码，且须对在用户账号密码下发生的所有活动承担责任。用户有权根据需要更改登录密码。因用户的过错导致的任何损失由用户自行承担，该过错包括但不限于：不按照提示操作、不按照平台流程操作、遗忘或泄漏密码或者验证码、密码被他人破解及用户使用的计算机被他人侵入等情形。
          </span>
        </p>
        <p>
          5.4
          用户应当向本平台提供真实准确的开通账户所需信息，包括但不限于真实姓名、手机号码（手机号码即为用户在本平台的账户）等。保证本平台可以通过上述联系方式与用户进行联系。同时，
          <span className='underline-bold'>
            用户也应当在相关资料实际变更时及时更新有关用户资料，因未及时更新资料导致的任何损失由用户自行承担。
          </span>
        </p>
        <p>
          5.5
          <span className='underline-bold'>
            用户在本平台的账号名称及发布的内容，不得有下列情形：
          </span>
        </p>
        <p className='underline-bold'>（1）违反中国宪法或法律法规规定的；</p>
        <p className='underline-bold'>
          （2）危害国家安全，泄露国家秘密，颠覆国家政权，破坏国家统一的；
        </p>
        <p className='underline-bold'>（3）损害国家荣誉和利益的，损害公共利益的；</p>
        <p className='underline-bold'>（4）煽动民族仇恨、民族歧视，破坏民族团结的；</p>
        <p className='underline-bold'>（5）破坏国家宗教政策，宣扬邪教和封建迷信的；</p>
        <p className='underline-bold'>（6）散布谣言，扰乱社会秩序，破坏社会稳定的；</p>
        <p className='underline-bold'>
          （7）散布淫秽、色情、赌博、暴力、凶杀、恐怖或者教唆犯罪的；
        </p>
        <p className='underline-bold'>（8）侮辱或者诽谤他人，侵害他人合法权益的；</p>
        <p className='underline-bold'>（9）含有法律、行政法规禁止的其他内容的。</p>
        <p>
          5.6
          <span className='underline-bold'>
            用户在本平台上所实施行为，不得违反国家法律、法规、行政规章的规定，不得侵犯他人知识产权或其他合法权益的信息，不得违背社会公共利益或公共道德，不得违反本平台的相关规定。
          </span>
        </p>
        <p>
          5.7
          <span className='underline-bold'>
            用户承诺自己在使用本平台实施的所有行为遵守法律、法规、行政规章和本平台的相关规定以及各种社会公共利益或公共道德。如有违反导致任何法律后果的发生，用户将以自己的名义独立承担相应的法律责任。
          </span>
        </p>
        <p>
          5.8
          用户在本平台网上操作过程中如与其他用户因产生纠纷，可以请求本平台从中予以协调处理。用户如发现其他用户有违法或违反本协议的行为，可以向本平台举报。
        </p>
        <p>
          5.9
          <span className='bold-text'>用户不得使用以下方式登录平台或破坏本平台所提供的服务：</span>
        </p>
        <p className='underline-bold'>
          （1）以任何机器人软件、蜘蛛软件、爬虫软件、刷屏软件或其它自动方式访问或登录本平台；
        </p>
        <p className='underline-bold'>
          （2）通过任何方式对本平台内部结构造成或可能造成不合理或不合比例的重大负荷的行为；
        </p>
        <p className='underline-bold'>
          （3）通过任何方式干扰或试图干扰本平台的正常工作或本平台上进行的任何活动。
        </p>
        <p>
          5.10
          <span className='underline-bold'>
            用户同意接收来自本平台的信息，包括但不限于平台内部弹窗、手机短信、手机消息通知等。
          </span>
        </p>
        <p>
          5.11
          <span className='underline-bold'>
            用户如为非自然人用户的，其在本平台实名认证的管理人员的所有操作视为用户行为，用户须对其管理人员的行为承担一切责任。用户应要求其管理的人员遵守本协议及本平台相关规则等要求，如用户实名认证的管理人员违反本协议及/或本平台规则等要求的，视为用户违反上述要求，用户应按照本协议要求承担相应责任。
          </span>
        </p>
        <p className='bold-text'>第6条 本平台的权利和义务</p>
        <p>6.1 本平台，是一个信息服务平台，为用户提供信息查询、信息采集服务。</p>
        <p>
          6.2
          本平台有义务在现有技术水平的基础上努力确保网上交流平台的正常运行，尽力避免因平台原因导致服务中断，若因不可避免的原因中断服务，平台将把中断时间限制在最短时间内，保证用户网上交流活动的顺利进行。
        </p>
        <p>
          6.3
          用户因在本平台实施活动过程中与其他用户产生纠纷的，用户将纠纷告知本平台，或本平台知悉纠纷情况的，经审核后，本平台有权通过电子邮件及联系电话向纠纷双方了解纠纷情况，并将所了解的情况通过电子邮件互相通知对方；用户通过司法机关依照法定程序要求本平台提供相关资料，本平台将积极配合并提供有关资料。
        </p>
        <p>
          6.4
          <span className='underline-bold'>
            因网上信息平台的特殊性，本平台不承担对所有用户的操作行为进行事先审查的义务，但如发生以下情形，本平台有权无需征得用户的同意限制用户的活动、向用户核实有关资料、发出警告通知、暂时中止、无限期中止及拒绝向该用户提供服务：
          </span>
        </p>
        <p className='underline-bold'>（1）用户违反本协议的；</p>
        <p className='underline-bold'>
          （2）存在用户或其他第三方通知本平台，认为某个用户或具体交易事项存在违法或不当行为，并提供相关证据，而本平台无法联系到该用户核证或验证该用户向本平台提供的任何资料的；
        </p>
        <p className='underline-bold'>
          （3）存在用户或其他第三方通知本平台，认为某个用户或具体事项存在违法或不当行为，并提供相关证据。本平台以普通非专业人员的知识水平标准对相关内容进行判别，可以认为这些内容或行为存在显著可能会对他方或本平台造成财务损失或承担法律责任的。
        </p>
        <p>
          6.5
          <span className='underline-bold'>
            根据国家法律、法规、行政规章规定、本协议的内容和本平台所掌握的事实依据，可以认定该用户存在违法或违反本协议行为或在本平台交易平台上存在其他不当行为，本平台有权无需征得用户的同意在本平台上以网络发布形式公布对该用户匿名化处理后的违法行为，并有权随时作出对该用户终止服务提供等处理。
          </span>
        </p>
        <p>
          6.6
          <span className='underline-bold'>
            本平台有权在不通知用户的前提下，删除或采取其他限制性措施处理下列信息：包括但不限于违反法律法规、公共利益或可能严重损害本平台和其他用户合法利益的信息。
          </span>
        </p>
        <p className='bold-text'>第7条 免责声明</p>
        <p>当用户接受该协议时，用户应当明确了解并同意：</p>
        <p>
          7.1
          <span className='underline-bold'>
            要易云对于您自本平台而获得的所有要易云以外主体发布的信息、内容等（以下统称“信息”），除法律明确规定外，不保证真实、准确和完整性。如果任何单位或者个人通过上述“信息”而进行任何行为，您须自行甄别真伪和谨慎预防风险。无论何种原因，要易云不对任何非与要易云直接发生的交易或行为承担任何直接、间接、附带或衍生的损失和责任。
          </span>
        </p>
        <p>
          7.2
          <span className='underline-bold'>
            本平台是在现有技术基础上提供的服务，本平台不能随时预见到任何技术上的问题或其他困难。该等困难可能会导致数据损失或其他服务中断。本平台不保证以下事项：
          </span>
        </p>
        <p className='underline-bold'>（1）本平台将符合所有用户的需求；</p>
        <p className='underline-bold'>（2）本平台不受干扰、能够随时响应、安全可靠或免于出错；</p>
        <p className='underline-bold'>（3）本服务使用权的取得结果是正确或可靠的。</p>
        <p>
          7.4
          <span className='underline-bold'>
            是否经由本平台下载或取得任何非由本平台提供的资料，由用户自行考虑、衡量并且自负风险，因下载任何资料而导致用户电脑系统的任何损坏或资料流失，用户应负完全责任。
          </span>
        </p>
        <p>
          7.5
          <span className='underline-bold'>
            用户经由本平台取得的建议和资讯，无论其形式或表现，均不构成要易云对用户通过本平台进行交易所作出的任何明示或暗示的保证或担保。
          </span>
        </p>
        <p>
          7.6
          <span className='underline-bold'>
            基于以下原因而造成的利润、商誉、使用、资料损失或其它无形损失，本平台不承担任何直接、间接、附带、特别、衍生性或惩罚性赔偿：
          </span>
        </p>
        <p className='underline-bold'>（1）本平台的使用或无法使用；</p>
        <p className='underline-bold'>（2）用户的传输或资料遭到未获授权的存取或变更；</p>
        <p className='underline-bold'>（3）本平台中任何第三方之声明或行为；</p>
        <p className='underline-bold'>（4）本平台其它相关事宜。</p>
        <p>
          7.7
          <span className='underline-bold'>
            本平台是为用户提供信息查询及收集服务的第三方平台，对于所查询及收集的信息的合法性、真实性等，本平台一律不负任何担保责任。
          </span>
        </p>
        <p>
          7.8
          <span className='underline-bold'>
            本平台提供的与其它互联网平台或资源的链接，用户可能会因此链接至其它运营商经营的平台，但不表示本平台与这些运营商有任何关系。其它运营商经营的平台均由各经营者自行负责，不属于本平台控制及负责范围之内。对于存在或来源于此类平台或资源的任何内容、广告、物品或其它资料，本平台亦不予保证或负责。因使用或依赖任何此类平台或资源发布的或经由此类平台或资源获得的任何内容、物品或服务所产生的任何损害或损失，本平台不负任何直接或间接的责任。
          </span>
        </p>
        <p>
          7.9
          <span className='underline-bold'>就下列情形的发生，本平台不承担任何法律责任：</span>
        </p>
        <p className='underline-bold'>
          （1）由于您将账号、密码告知他人或与他人共享注册账户，由此导致的任何个人信息的泄漏，或其他非因本平台原因导致的个人信息的泄漏；
        </p>
        <p className='underline-bold'>
          （2）您在申请使用平台服务时因个人资料有任何变动，但未能及时更新，由此导致个人信息不真实而引起的问题及后果；
        </p>
        <p className='underline-bold'>
          （3）本平台根据法律规定、政策要求或行政/司法机关的要求对外提供您的个人信息或交易记录；
        </p>
        <p className='underline-bold'>
          （4）因不可抗力导致的任何后果。本用户协议中的“不可抗力”之定义，详见本协议第12.1条的相关表述。
        </p>
        <p className='bold-text'>第8条 知识产权</p>
        <p>
          8.1
          <span className='underline-bold'>
            本平台及本平台所使用的任何相关软件、程序、内容，包括但不限于作品、图片、档案、资料、平台构架、平台版面的安排、网页设计、经由本平台或广告商向用户呈现的广告或资讯，均由本平台或法定权利人依法享有相应的知识产权，包括但不限于著作权、商标权、专利权或其它专属权利等，受到相关法律的保护。未经本平台或权利人明示授权，用户不得擅自复制、传播、展示、镜像、上传、下载、使用、修改、出租、出借、出售、散布上述任何资料和资源，或根据上述资料和资源制作成任何种类产品，或者从事任何其它侵犯知识产权的行为，否则，平台有权追求侵权人的相关法律责任。
          </span>
        </p>
        <p>
          8.2
          <span className='underline-bold'>
            本平台授予用户不可转移及非专属的使用权，使用户可以通过单独计算机使用本平台的目标代码（以下简称“软件”），但用户不得且不得允许任何第三方复制、修改、创作衍生作品、进行还原工程、反向组译，或以其它方式破译或试图破译源代码，或出售、转让“软件”或对“软件”进行再授权，或以其它方式移转“软件”之任何权利。用户同意不以任何方式修改“软件”，或使用修改后的“软件”。
          </span>
        </p>
        <p>
          8.3
          您在使用要易云服务时利用本平台及服务所发表上传的文字、图片、视频等原创信息的知识产权归您所有（或由第三方内容提供方和您另行约定）。
          <span className='underline-bold'>
            您在此明确授权：您上传到本平台服务器上的任何内容，您皆授予本平台在世界范围内基于商业或非商业目的，永久的、免费的以复制、翻译、发行、重新编排、节选等方式使用，或采用任何形式再传播或创作改变或衍生作品的权利。
          </span>
        </p>
        <p>
          8.4
          <span className='underline-bold'>
            基于对数据的合法加工而获得的具有竞争性的数据权益，除法律法规另有规定外，要易云享有独立的使用权益而无须获得您的同意。
          </span>
        </p>
        <p>
          8.5
          <span className='underline-bold'>
            在未得到著作权人的授权时，您不得将他人的作品全部或部分复制发表到本平台系统。如您上传的内容侵犯了第三方的著作权或其他权利，本平台将不承担任何法律责任，所有后果由您自行承担。如果第三方提出关于著作权的异议，本平台有权根据实际情况删除相关的内容，并有权追究您的法律责任。因您的侵权行为给本平台或任何第三方造成损失的，您应负责全部赔偿责任。
          </span>
        </p>
        <p>
          8.6
          关于信息内容的投诉或举报。若您在使用平台过程中，不慎受到合法权益的侵犯，您有权通知要易云采取必要措施进行处置。若您在使用平台过程中，发现存在违法违规或违反本服务相关规则的情况，您也有权向要易云发起举报，要易云亦会及时采取必要措施（删除、屏蔽、断开链接或限制使用功能等）进行处置。
        </p>
        <p>
          8.7
          <span className='underline-bold'>
            内容维权授权。在法律法规允许的范围内，您同意并授权要易云就侵犯您合法权益的行为（包括但不限于私自复制、使用、编辑、抄袭等行为）采取任何形式的法律行动，包括但不限于投诉、诉讼等必要的维权措施。
          </span>
        </p>
        <p>
          8.8
          <span className='underline-bold'>用户不得经由非本平台所提供的界面使用本平台。</span>
        </p>
        <p className='bold-text'>第9条 用户行为规范</p>
        <p>
          9.1
          <span className='underline-bold'>
            您保证合理地使用本平台服务，并接受本协议和要易云适时制定并发布的其他政策、规则、公告声明。
          </span>
        </p>
        <p>
          9.2
          <span className='underline-bold'>
            行为禁止：您可在本协议约定的范围内使用本平台及服务，您不得利用本平台从事以下行为：
          </span>
        </p>
        <p className='underline-bold'>（1）超出授权或恶意使用平台服务；</p>
        <p className='underline-bold'>
          （2）利用本平台发表、传送、传播、储存危害国家安全、国家统一、社会稳定的内容，或侮辱诽谤、色情、暴力、引起他人不安及任何违反国家法律法规政策的内容，或者设置含有上述内容的网名、角色名，发布、传送、传播违法广告信息、营销信息及垃圾信息等；
        </p>
        <p className='underline-bold'>
          （3）利用本平台侵害他人知识产权、肖像权、隐私权、名誉权、个人信息等合法权利或权益；
        </p>
        <p className='underline-bold'>（4）恶意虚构或协助虚构事实、评价等信息或数据；</p>
        <p className='underline-bold'>
          （5）进行任何危害计算机网络安全的行为，包括但不限于：使用未经许可的数据或进入未经许可的服务器/账户；未经允许进入公众计算机网络或者他人计算机系统并删除、修改、增加存储信息；未经许可，企图探查、扫描、测试本“软件”系统或网络的弱点或其它实施破坏网络安全的行为；企图干涉、破坏本“软件”系统或网站的正常运行，故意传播恶意程序或病毒以及其他破坏干扰正常网络信息服务的行为；伪造TCP/IP数据包名称或部分名称；利用本平台及服务上传任何病毒、木马，或者蠕虫等危害网络健康的内容；
        </p>
        <p className='underline-bold'>
          （6）对本平台进行反向工程、反向编译或反向汇编或以其它方式企图发现平台的源代码和算法，未经许可修改、禁用软件的任何功能或创建基于软件的衍生作品。去除本平台或文档上的任何所有权声明或标签，或将其他软件与本平台合并；
        </p>
        <p className='underline-bold'>
          （7）进行任何破坏要易云提供服务公平性或者其他影响应用正常秩序的行为，如主动或被动刷分、合伙作弊、使用外挂或者其他的作弊软件、利用BUG（又叫“漏洞”或者“缺陷”）来获得不正当的非法利益，或者利用互联网或其他方式将外挂、作弊软件、BUG公之于众；
        </p>
        <p className='underline-bold'>
          （8）从事其他法律法规、政策及公序良俗、社会公德禁止的行为以及侵犯其他个人、公司、社会团体、组织的合法权益的行为。
        </p>
        <p className='underline-bold'>
          9.3
          信息内容规范：为了营造良好网络生态，保障公民、法人和其他组织的合法权益，维护国家安全和公共利益，要易云将根据法律、行政法规，营造清朗的网络空间，并开展弘扬正能量、处置违法和不良信息等相关活动。
        </p>
        <p>
          9.3.1
          <span className='underline-bold'>您不得制作、复制、发布含有下列内容的违法信息：</span>
        </p>
        <p className='underline-bold'>（1）反对中国宪法所确定的基本原则的；</p>
        <p className='underline-bold'>
          （2）危害国家安全，泄露国家秘密，颠覆国家政权，破坏国家统一的；
        </p>
        <p className='underline-bold'>（3）损害国家荣誉和利益的；</p>
        <p className='underline-bold'>
          （4）歪曲、丑化、亵渎、否定英雄烈士事迹和精神，以侮辱、诽谤或者其他方式侵害英雄烈士的姓名、肖像、名誉、荣誉的；
        </p>
        <p className='underline-bold'>
          （5）宣扬恐怖主义、极端主义或者煽动实施恐怖活动、极端主义活动的；
        </p>
        <p className='underline-bold'>（6）煽动民族仇恨、民族歧视，破坏民族团结的；</p>
        <p className='underline-bold'>（7）破坏国家宗教政策，宣扬邪教和封建迷信的；</p>
        <p className='underline-bold'>（8）散布谣言，扰乱经济秩序和社会秩序的；</p>
        <p className='underline-bold'>
          （9）散布淫秽、色情、赌博、暴力、凶杀、恐怖或者教唆犯罪的；
        </p>
        <p className='underline-bold'>
          （10）侮辱或者诽谤他人，侵害他人名誉、隐私和其他合法权益的；
        </p>
        <p className='underline-bold'>（11）法律、行政法规禁止的其他内容。</p>
        <p>
          9.3.2
          <span className='underline-bold'>
            要易云也将依法采取措施，防范和抵制制作、复制、发布含有下列内容的不良信息：
          </span>
        </p>
        <p className='underline-bold'>（1）使用夸张标题，内容与标题严重不符的；</p>
        <p className='underline-bold'>（2）炒作绯闻、丑闻、劣迹等的；</p>
        <p className='underline-bold'>（3）不当评述自然灾害、重大事故等灾难的；</p>
        <p className='underline-bold'>（4）带有性暗示、性挑逗等易使人产生性联想的；</p>
        <p className='underline-bold'>（5）展现血腥、惊悚、残忍等致人身心不适的；</p>
        <p className='underline-bold'>（6）煽动人群歧视、地域歧视等的；</p>
        <p className='underline-bold'>（7）宣扬低俗、庸俗、媚俗内容的；</p>
        <p className='underline-bold'>
          （8）可能引发未成年人模仿不安全行为和违反社会公德行为、诱导未成年人不良嗜好等的；
        </p>
        <p className='underline-bold'>（9）其他对网络生态造成不良影响的内容。</p>
        <p>
          9.4
          <span className='underline-bold'>信息内容的使用规范</span>
        </p>
        <p className='underline-bold'>
          未经要易云书面许可，您不得自行或授权、允许、协助任何第三人对本平台中信息内容进行如下行为：
        </p>
        <p className='underline-bold'>
          （1）复制、读取、采用本平台的信息内容，用于任何形式的商业用途；
        </p>
        <p className='underline-bold'>
          （2）擅自编辑、整理、编排平台及相关服务的信息内容后在平台及相关服务的源页面以外的渠道进行展示；
        </p>
        <p className='underline-bold'>
          （3）采用不正当方式，自行或协助第三人对本平台及相关服务的信息内容产生流量、阅读量或交易引导、转移、劫持等不利影响。
        </p>
        <p className='bold-text'>第10条 个人信息保护与隐私政策</p>
        <p>
          10.1
          尊重用户隐私并保护您的个人信息安全是要易云的一贯态度，平台将会采取合理的措施保护您的个人信息与隐私。
        </p>
        <p>10.2 信息使用</p>
        <p className='underline-bold'>
          （1）要易云有权在遵守法律法规的前提下，以明示的方式获取、使用、储存和分享您的个人信息。要易云不会在未经您授权时，公开、编辑或透露您的个人信息及您保存在要易云的非公开内容。您同意并保证：本平台有权依法收集使用您的相关信息。
        </p>
        <p>（2）本平台不会向任何人出售或出借用户的个人或法人信息，除非事先得到用户得许可；</p>
        <p className='underline-bold'>
          （3）本平台亦不允许任何第三方以任何手段收集、编辑、出售或者无偿传播用户的个人或法人信息。任何用户如从事上述活动，一经发现，本平台有权立即终止与该用户的服务协议，查封其账号。
        </p>
        <p className='underline-bold'>
          （4）您同意，要易云有权通过cookie等技术收集您的使用、行为信息，并在经过数据脱敏使之不再指向、关联到您个人的身份信息时，自由使用脱敏后的纯商业数据。当然，您也可根据自己的偏好删除Cookie，但如果您这么做，则需要在每一次访问要易云的网站时亲自更改用户设置。目前删除Cookie的一般路径是浏览器：“设置-清除数据”，或者将手机系统还原/清除。
        </p>
        <p>10.3 信息披露</p>
        <p className='underline-bold'>用户的信息将在下述情况下部分或全部被披露：</p>
        <p className='underline-bold'>（1）经用户同意，向第三方披露；</p>
        <p className='underline-bold'>
          （2）根据法律的有关规定，或者行政、司法机关的要求，向第三方或者行政、司法机关披露；
        </p>
        <p className='underline-bold'>
          （3）若用户出现违反中国有关法律或者平台规定的情况，需要向第三方披露；
        </p>
        <p className='underline-bold'>
          （4）为保护您、本平台的其他用户或本平台的关联方的合法权益，本平台可能将您的个人信息用于预防、发现、调查以下事项：欺诈、危害安全、违法或违反与本平台或关联方协议、政策或规则的行为；
        </p>
        <p className='underline-bold'>
          （5）在遵循隐私权保护以及其他相应的保密安全措施的前提下，允许本平台将您的个人信息提供给相关合作方，让其根据本平台指令处理相关信息；
        </p>
        <p className='underline-bold'>（6）其它本平台根据法律法规认为合适的披露。</p>
        <p className='underline-bold'>若您不同意以上内容，请立即停止使用要易云平台服务。</p>
        <p>10.4 信息安全</p>
        <p>
          （1）要易云将运用各种安全技术和程序建立完善的管理制度来保护您的个人信息及隐私安全，以免遭受未经授权的访问、使用或披露。
        </p>
        <p>
          （2）如果用户发现自己的个人或法人信息泄密，尤其是用户账户或密码发生泄露，请用户立即联络本平台客服，以便要易云采取相应措施。
        </p>
        <p>
          10.5
          <span className='underline-bold'>
            在遵守本协议项下特别约定的个人信息保护与隐私政策外，要易云希望您认真并完整阅读要易云特别针对平台而制定并适时发布的《隐私政策》，这将更有助于保障您的个人信息。
          </span>
        </p>
        <p className='bold-text'>第11条 信息或广告推送</p>
        <p>
          您同意在接受要易云提供服务的同时，允许要易云在遵守法律法规的前提下自行或由第三方广告商通过平台内弹窗、手机系统弹窗、手机短信、电子邮件等方式向您发送、展示广告、推广或宣传信息（包括商业与非商业信息）。如您对发送、推荐的广告或信息不感兴趣，您可以基于要易云提供的相关技术选项，控制系统向您展示或不展示/减少展示相关类型的广告或信息。
        </p>
        <p className='bold-text'>第12条 不可抗力</p>
        <p>
          12.1
          <span className='underline-bold'>
            鉴于互联网服务的特殊性，您理解并同意要易云在因不可抗力或者其他意外事件导致平台及服务障碍不能正常运作、服务中断或延迟等情形下，对您在本平台所遭受的损失（包括但不限于财产、收益、数据资料等方面的损失或其它无形损失）无需承担责任。同时，因不可抗力使得本协议的履行不可能、不必要或者无意义的，任何一方均可单方解除本协议且无需承担违约责任。
          </span>
        </p>
        <p>
          本协议所称之不可抗力意指不能预见、不能避免并不能克服的客观情况，包括但不限于战争、台风、水灾、火灾、雷击或地震、罢工、暴动、法定疾病、停电、计算机病毒、木马、其他恶意程序、黑客攻击、网络病毒、电信部门技术管制、网络运营公司技术调整或故障、系统维护、政府行为或任何其它自然或人为造成的灾难等客观情况。
        </p>
        <p>
          12.2
          若任何一方由于不可抗力无法履行协议，该方须及时通知另一方以便减轻另一方可能遭受的损失，并应在合理的时间内提供不可抗力的证明。
        </p>
        <p className='bold-text'>第13条 保密</p>
        <p className='underline-bold'>
          用户保证在使用本平台过程中所获悉的属于本平台、本平台其他用户及其他第三方的无法自公开渠道获得的文件及资料（包括但不限于商业秘密、公司计划、运营活动、财务信息、技术信息、经营信息及其他商业秘密）予以保密。未经该资料和文件的原提供方同意，用户不得向第三方泄露该商业秘密的全部或者部分内容。但法律、法规、行政规章另有规定或者双方另有约定的除外。
        </p>
        <p className='bold-text'>第14条 违约责任</p>
        <p>
          14.1
          <span className='underline-bold'>
            如果您在使用本平台服务的过程中违反本协议约定、本平台其他规则、协议，或其他可适用的法律法规、国家政策、合同约定、平台规则或公告的，本平台有权要求您改正或直接采取一切必须要的措施以减轻或消除您的不当行为所带来的负面影响，并可根据违规情形严重情况要求您承担违约责任，具体措施包括但不限于：
          </span>
        </p>
        <p className='underline-bold'>（1）警告；</p>
        <p className='underline-bold'>（2）违规情形的平台内公示；</p>
        <p className='underline-bold'>（3）修改或屏蔽违规内容，包括但不限于将违规信息移除；</p>
        <p className='underline-bold'>（4）限制信息发布，限制平台其他功能的使用；</p>
        <p className='underline-bold'>（5）部分或全部扣除相关费用；</p>
        <p className='underline-bold'>（6）部分或全部扣除保证金（如有）；</p>
        <p className='underline-bold'>（7）锁定用户账号，中断向您提供本平台服务；</p>
        <p className='underline-bold'>
          （8）锁定您的账号，终止向您提供服务，和/或拒绝或限制您再行注册或使用本平台服务；
        </p>
        <p className='underline-bold'>（9）要求您承担损害赔偿责任。</p>
        <p>
          14.2
          <span className='underline-bold'>
            若您的行为给我们造成损失的（包括但不限于直接损失、名誉损失、第三方的罚款、索赔等），我们有权全额向您追偿，如您在本平台中有保证金等财产权益的，我们有权冻结。
          </span>
        </p>
        <p>
          14.3
          <span className='underline-bold'>
            本协议终止后，除法律有明确规定外，本平台无义务向您或您指定的第三方披露您账户中的任何信息。本协议终止后，本平台仍享有下列权利：根据法律规定，继续保存您留存于本平台的的各类信息，具体的存储期限，详见《隐私政策》的相关规定；对于您过往的违约行为，本平台仍可依据本协议向您追究违约责任。
          </span>
        </p>
        <p className='underline-bold'>
          14.4
          本协议及本平台其他规则、协议项下所述“损失”或“赔偿责任”，均包括但不限于自身损失、向第三方支付的违约金、赔偿金及因实现权利而产生的律师费、取证费、诉讼/仲裁费、财产保全费等。
        </p>
        <p className='bold-text'>第15条 纠纷解决方式 15.1</p>
        <p>
          本协议及其规则的有效性、履行和与本协议及其规则效力有关的所有事宜，将受中华人民共和国法律管辖，任何争议仅适用中华人民共和国法律。
        </p>
        <p>
          15.2
          本平台有权受理并调处用户之间因承接服务产生的纠纷。因本平台非司法机关，您完全理解并承认，本平台对证据的鉴别能力及对纠纷的处理能力有限，调节纠纷完全是基于用户委托，不保证处理结果符合用户的期望，本平台有权决定是否参与争议的调处。
        </p>
        <p>
          15.3
          凡因履行本协议及其规则发生的纠纷以及因使用本平台服务而产生的所有与本平台的纠纷，双方应先协商解决，协商不成的，提交深圳国际仲裁院依据其现行有效的仲裁规则进行仲裁。
        </p>
        <p>
          15.4
          用户已知悉并确认：对于因用户使用本平台争议引起的纠纷，仲裁机构可以通过手机短信等现代通讯方式送达法律文书；指定接收法律文书的手机号码为用户登录时输入的手机号码；仲裁机构可采取一种或多种送达方式送达法律文书，送达时间以上述送达方式中最先送达的为准；上述送达方式适用于各个仲裁阶段；用户保证其手机号码与电子邮箱准确、有效，如果提供的送达信息不准确，或者不及时告知变更后的送达信息，使法律文书无法送达或未及时送达，自行承担由此可能产生的法律后果。
        </p>
        <p className='bold-text'>第16条 完整协议</p>
        <p>
          16.1
          本协议由本协议条款与本平台公示的各项规则组成，相关名词可互相引用参照，如有不同理解，以本协议条款为准。
        </p>
        <p>
          16.2
          用户一旦确认对本协议理解和认同，即对本协议所有组成部分的内容理解并认同，一旦用户使用本平台提供的服务，即受本协议所有组成部分的约束。
        </p>
        <p className='bold-text'>第17条 协议修改及解释</p>
        <p>
          17.1
          本协议内容包括本协议条款及平台不时发布或组织订立的各类协议、平台规则和公告。所有签署内容均为本协议不可分割的组成部分，与本协议正文具有同等法律效力。
        </p>
        <p>
          17.2 本协议所有条款的标题仅为阅读方便，本身并无实际涵义，不能作为本协议涵义解释的依据。
        </p>
        <p>17.3 本协议条款无论因何种原因部分无效或不可执行，其余条款仍有效，对双方具有约束力。</p>
        <p>
          17.4 修改与更新：
          <span className='underline-bold'>
            要易云有权根据法律法规变化、维护平台秩序、保护消费者合法权益的需要，在必要时修改本协议（包括适时制定并发布其他政策、规则、公告声明），当您登录本平台时会自动弹出变更后的协议，若您同意变更后的内容，请点击“同意”按钮并继续登陆本平台使用平台服务，若您不同意变更后的内容，您将无法使用本平台服务，同时应及时与平台客服取得联系，本平台将根据情况审核确认给予您一定的时限完成您账户下尚未完结的事项，在已有事项全部完结后锁定您的账户，此期间您将无法继续开展新的业务。
          </span>
        </p>
        <p className='underline-bold'>
          17.5
          您使用本平台即视为您已阅读并同意受本协议的约束。要易云有权在必要时修改本协议条款。您可以在本平台的最新版本中查阅相关协议条款。本协议条款变更后，如果您继续使用本凭条，即视为您已接受修改后的协议。如果您不接受修改后的协议，应当停止使用本平台。
        </p>
        <p className='bold-text'>第18条 通知与送达</p>
        <p>
          18.1
          <span className='bold-text'>有效联系方式</span>
        </p>
        <p className='underline-bold'>
          您在成为本平台用户并接受本平台服务时，您应该向本平台提供真实有效的联系方式（包括您的手机号码等），对于联系方式发生变更的，您有义务及时更新有关信息，并保持可被联系的状态。您在成为本平台用户时生成的用于登录本平台接收站内信、系统消息的用户账号，也作为您的有效联系方式。
        </p>
        <p className='underline-bold'>
          本平台将向您的上述联系方式的其中之一或其中若干向您送达各类通知，而此类通知的内容可能对您的权利义务产生重大的有利或不利影响，请您务必及时关注。
        </p>
        <p className='underline-bold'>
          您有权通过您登录时用的手机号码获取您感兴趣的商品广告信息、促销优惠等商业性信息；您如果不愿意接收此类信息，您有权通过本平台提供的相应的退订功能进行退订。
        </p>
        <p>
          18.2
          <span className='bold-text'>通知与送达</span>
        </p>
        <p className='underline-bold'>
          本平台通过上述联系方式向您发出通知，其中以电子方式发出的书面通知，包括但不限于在本平台公告，向您提供的联系电话发送手机短信，向您的账号发送系统消息以及站内信息，在发送成功后即视为送达；以纸质载体发出的书面通知，按照提供联系地址交邮后的第五个自然日即视为送达。
        </p>
        <p className='underline-bold'>
          对于与本平台产生的任何纠纷，您同意司法机关（包括但不限于人民法院）可以通过手机短信、电子邮件等现代通讯方式或邮寄方式向您送达法律文书（包括但不限于诉讼文书）。您指定接收法律文书的手机号码、电子邮箱等联系方式为您在平台注册、更新时提供的手机号码、电子邮箱，司法机关向上述联系方式发出法律文书即视为送达。您指定的邮寄地址为您的法定联系地址或您提供的有效联系地址。
        </p>
        <p className='underline-bold'>
          您同意司法机关可采取以上一种或多种送达方式向您达法律文书，司法机关采取多种方式向您送达法律文书，送达时间以上述送达方式中最先送达的为准。
        </p>
        <p className='underline-bold'>您同意上述送达方式适用于各个司法程序阶段。</p>
        <p className='underline-bold'>
          你应当保证所提供的联系方式是准确、有效的，并进行实时更新。如果因提供的联系方式不确切，或不及时告知变更后的联系方式，使法律文书无法送达或未及时送达，由您自行承担由此可能产生的法律后果。
        </p>
        <p className='bold-text'>第19条 附则</p>
        <p>
          19.1
          <span className='underline-bold'>
            用户在登录使用前应认真阅读本协议的全部内容，如对协议有任何疑问，可向要易云咨询。本协议对登录使用、激活成功之后的用户产生法律约束力，届时用户不得以未阅读本协议内容或未获得本平台对问题的解答等为由，主张本协议无效或要求撤销本协议。
          </span>
        </p>
        <p>19.2 要易云对本协议保留一切解释和修改的权利。</p>
        <p className='bold-text'>第20条 联系要易云</p>
        <p>如果您有任何的疑问、投诉、意见和建议，欢迎您与要易云沟通反馈。要易云的联系方式见下：</p>
        <p>客服邮箱：changtianchen@yaoyi.net</p>
        <p>联系地址：深圳市福田区莲花街道福中社区福中三路1006号诺德金融中心17A</p>
        <p>（正文完）</p>
      </AgreementWrapper>
    </Modal>
  )
}

const AgreementWrapper = styled.div`
  p:not(.title) {
    text-indent: 2em;
    line-height: 1.5em;
  }
  .underline-bold {
    text-decoration: underline;
    font-weight: bold;
  }
  .bold-text {
    font-weight: bold;
  }
`
